@@ -1,6 +1,4 @@
-#![unstable]
-#![feature(into_cow)]
-#![cfg_attr(test, feature(core, test))]
+#![cfg_attr(test, feature(test))]
 
 //!This crate contains parser combinators, roughly based on the Haskell library [parsec](http://hackage.haskell.org/package/parsec).
 //!
@@ -81,7 +79,7 @@
 extern crate test;
 
 #[doc(inline)]
-pub use primitives::{Parser, ParseResult, ParseError};
+pub use primitives::{Parser, ParseResult, ParseError, from_iter};
 #[doc(inline)]
 pub use char::{
     any_char,
@@ -140,7 +138,6 @@ pub mod char;
 mod tests {
     use super::*;
     use super::primitives::{SourcePosition, State, Stream, Error, Consumed};
-    use std::borrow::IntoCow;
     
 
     fn integer<'a, I>(input: State<I>) -> ParseResult<i64, I>
@@ -168,9 +165,9 @@ mod tests {
     }
     #[test]
     fn iterator() {
-        let result = parser(integer).parse("123".chars())
-            .map(|(i, mut input)| (i, input.next()));
-        assert_eq!(result, Ok((123i64, None)));
+        let result = parser(integer).parse(from_iter("123".chars()))
+            .map(|(i, input)| (i, input.uncons().err()));
+        assert_eq!(result, Ok((123i64, Some(()))));
     }
     #[test]
     fn field() {
@@ -252,10 +249,10 @@ r"
             position: SourcePosition { line: 2, column: 1 },
                 errors: vec![
                     Error::Unexpected(','),
-                    Error::Expected("identifier".into_cow()),
-                    Error::Expected("integer".into_cow()),
-                    Error::Expected("[".into_cow()),
-                    Error::Expected("(".into_cow()),
+                    Error::Expected("identifier".into()),
+                    Error::Expected("integer".into()),
+                    Error::Expected("[".into()),
+                    Error::Expected("(".into()),
                 ]
         };
         assert_eq!(result, Err(err));
@@ -410,7 +407,7 @@ r"(3 * 4) + 2 * 4 * test + 4 * aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa
             try(string("Fig")),
             try(string("Grape")),
         ];
-        let mut parser = choice_slice(fruits.as_mut_slice());
+        let mut parser = choice_slice(&mut fruits[..]);
         assert_eq!(parser.parse("Apple"), Ok(("Apple", "")));
         assert_eq!(parser.parse("Banana"), Ok(("Banana", "")));
         assert_eq!(parser.parse("Cherry"), Ok(("Cherry", "")));
