@@ -1,5 +1,5 @@
 use std::fmt;
-use std::borrow::{Cow, IntoCow};
+use std::borrow::Cow;
 use std::error::Error as StdError;
 
 ///Struct which containing the current position
@@ -111,8 +111,8 @@ impl ParseError {
         ParseError { position: position, errors: vec![error] }
     }
     pub fn add_message<S>(&mut self, message: S)
-        where S: IntoCow<'static, str> {
-        self.add_error(Error::Message(message.into_cow()));
+        where S: Into<Cow<'static, str>> {
+        self.add_error(Error::Message(message.into()));
     }
     pub fn add_error(&mut self, message: Error) {
         //Don't add duplicate errors
@@ -237,7 +237,7 @@ impl <I: Stream> State<I> {
                 f(&mut position, &c);
                 Ok((c, Consumed::Consumed(State { position: position, input: input })))
             }
-            Err(()) => Err(Consumed::Empty(ParseError::new(position, Error::Message("End of input".into_cow()))))
+            Err(()) => Err(Consumed::Empty(ParseError::new(position, Error::Message("End of input".into()))))
         }
     }
 }
@@ -263,16 +263,6 @@ pub trait Stream : Clone {
     fn uncons(self) -> Result<(Self::Item, Self), ()>;
 }
 
-impl <I: Iterator + Clone> Stream for I {
-    type Item = <I as Iterator>::Item;
-    fn uncons(mut self) -> Result<(I::Item, Self), ()> {
-        match self.next() {
-            Some(x) => Ok((x, self)),
-            None => Err(())
-        }
-    }
-}
-
 impl <'a> Stream for &'a str {
     type Item = char;
     fn uncons(self) -> Result<(char, &'a str), ()> {
@@ -286,9 +276,32 @@ impl <'a> Stream for &'a str {
 impl <'a, T> Stream for &'a [T] {
     type Item = &'a T;
     fn uncons(self) -> Result<(&'a T, &'a [T]), ()> {
-        match self {
-            [ref x, rest..] => Ok((x, rest)),
-            [] => Err(())
+        if self.len() > 0 {
+            Ok((&self[0], &self[1..]))
+        }
+        else {
+            Err(())
+        }
+    }
+}
+
+#[derive(Clone, Debug)]
+pub struct IteratorStream<I>(I)
+    where I: Iterator + Clone;
+
+
+///Converts an `Iterator` into a stream.
+pub fn from_iter<I>(iter: I) -> IteratorStream<I>
+    where I: Iterator + Clone {
+    IteratorStream(iter)
+}
+
+impl <I: Iterator + Clone> Stream for IteratorStream<I> {
+    type Item = <I as Iterator>::Item;
+    fn uncons(mut self) -> Result<(I::Item, Self), ()> {
+        match self.0.next() {
+            Some(x) => Ok((x, self)),
+            None => Err(())
         }
     }
 }
